Cookie class
Properties
- creationTime ↔ DateTime
-
getter/setter pair
- domain ↔ String
-
getter/setter pair
- expiryTime ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- hostOnly ↔ bool
-
getter/setter pair
- httpOnly ↔ bool
-
getter/setter pair
- lastAccessTime ↔ DateTime
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- path ↔ String
-
getter/setter pair
- persistent ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secure ↔ bool
-
getter/setter pair
- value ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override